Procedural macros for the I/O event system.
This crate provides procedural macros for deriving event types and creating event subscribers.
It is part of the ioevent ecosystem and should be used as a dependency of ioevent.
Attribute Macros
- procedure
- Creates a procedure handler from an async function.
- subscriber
- Creates an event subscriber from an async function.
Derive Macros
- Event
- Derives the
Eventtrait for a type. - Procedure
Call - Derives the
ProcedureCalltrait for a type.